==> cmsmadesimple-1.8.2p0.tgz: cms/modules/FileManager/lang/ext/nb_NO.php <==
<?php
$lang['friendlyname'] = 'Filbehandler';
$lang['permission'] = 'Bruk at Filbehandler modulen';
$lang['permissionadvanced'] = 'Avansert bruk av Filbehandler modulen';
$lang['moddescription'] = 'Behandling av filer og kataloger i opplastings-filseksjonen av cmsms';
$lang['installed'] = 'Filbehandler versjon %s installert';
$lang['postinstall'] = 'Filbehandler modul ble installert';
$lang['uninstalled'] = 'Filbehandler modul avinstallert';
$lang['really_uninstall'] = 'Er du sikker p&aring; at Filbehandler modulen skal avinstalleres';
$lang['upgraded'] = 'Filbehandler modulen ble oppgradert til versjon %s';
$lang['fileview'] = 'Fil visning';
$lang['switchtofileview'] = 'Skift til fil visning';
$lang['settings'] = 'Innstillinger';
$lang['savesettings'] = 'Lagre innstillinger';
$lang['filename'] = 'Filnavn';
$lang['fileinfo'] = 'Filinfo ';
$lang['fileowner'] = 'Fileier';
$lang['fileperms'] = 'Tillatelser';
$lang['filesize'] = 'St&oslash;rrelse';
$lang['filedate'] = 'Dato';
$lang['actions'] = 'Handlinger';
$lang['delete'] = 'Slett';
$lang['notwritable'] = 'Ikke skrivbar';
$lang['filetoobig'] = 'er for stor. Opplasting avbrutt.';
$lang['unknown'] = 'Ukjent';
$lang['fileoutsideuploads'] = 'Du har IKKE tillatelse til &aring; modifisere filer utenfor uploads katalogen! (Dette vil kreve at du har tildelt Advanced File Management tillatelsen)';
$lang['writable'] = 'Skrivbar';
$lang['writeprotected'] = 'Skrivebeskyttet';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'Mb';
$lang['files'] = 'filer';
$lang['bytesin'] = 'bytes i';
$lang['in'] = 'i';
$lang['file'] = 'fil';
$lang['fileno'] = 'Filnr.';
$lang['subdirs'] = 'underkataloger';
$lang['subdir'] = 'underkatalog';
$lang['and'] = 'og';
$lang['confirmsingledelete'] = 'Er du sikker?';
$lang['confirmsingledirdelete'] = 'Er du sikker p&aring; at mappen skal slettes?';
$lang['dirtreedeletesuccess'] = 'Mappen inkludert innhold ble slettet.';
$lang['dirtreedeletefail'] = 'En feil oppstod under sletting av denne katalogen. Noe av innholdet kan likevel ha blitt slettet.';
$lang['singlefiledeletesuccess'] = 'Filen ble slettet';
$lang['filedeletesuccess'] = 'ble slettet';
$lang['singlefiledeletefail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; slette filen';
$lang['filedeletefail'] = ' ble ikke slettet grunnet en feil';
$lang['singledirdeletesuccess'] = 'Katalogen ble slettet';
$lang['singledirdeletefail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; slette katalogen (er den tom?)';
$lang['deleteselected'] = 'Slett de valgte filene';
$lang['confirmselected'] = 'Er du sikker?';
$lang['confirmdeleteselected'] = 'Er du sikker p&aring; at de valgte filene skal slettes?';
$lang['deleteselectedcancelled'] = 'Sletting av valgte filer avbrutt';
$lang['recursetext'] = 'Recurse into subdirs (not yet implemented)';
$lang['nofilesselected'] = 'Ingen filer valgt';
$lang['moveselected'] = 'Flytt de valgte filene';
$lang['copyselected'] = 'Kopier de valgte filene';
$lang['selecttargetdir'] = 'Velg m&aring;lmappe for &aring; flytte/kopiere';
$lang['movedto'] = 'flyttet til';
$lang['copiedto'] = 'kopiert til';
$lang['couldnotmove'] = 'kunne ikke flyttes';
$lang['couldnotcopy'] = 'kunne ikke kopieres';
$lang['rename'] = 'Omd&oslash;p';
$lang['newname'] = 'Nytt navn:';
$lang['renamesuccess'] = 'Filen ble omd&oslash;pt';
$lang['renamefailure'] = 'Omd&oslash;ping feilet';
$lang['renamecancelled'] = 'Omd&oslash;ping avbrutt';
$lang['owner'] = 'Eier(Owner)';
$lang['group'] = 'Gruppe(Group)';
$lang['others'] = 'Andre(Others)';
$lang['newpermissions'] = 'Nye rettigheter:';
$lang['setpermissions'] = 'Sett rettigheter';
$lang['permissionstyle'] = 'Rettighets stil';
$lang['rwxstyle'] = 'rwx stil';
$lang['755style'] = '755 stil';
$lang['quickmode'] = 'Quick chmod (f.eks. 777)';
$lang['chmod'] = 'Endre rettigheter';
$lang['chmodselected'] = 'Endre rettigheter p&aring; valgte filer';
$lang['chmodsuccess'] = 'Filen fikk nye rettigheter';
$lang['chmodfailure'] = 'Endring av rettigheter p&aring; filen feilet';
$lang['chmodcancelled'] = 'Endring av rettigheter avbrutt';
$lang['dirchmodfailmulti'] = '&Aring; endre rettigheter p&aring; katalogen mislyktes, men mulig noe av innholdet likevel kan ha f&aring;tt nye rettigheter.';
$lang['dirchmodsuccessmulti'] = 'Endre rettigheter p&aring; katalogen og dets innhold var vellykket';
$lang['dirchmodsuccess'] = 'Katalogen ble vellykket endret med nye rettigheter';
$lang['dirchmodfailure'] = 'Endring av rettigheter p&aring; katalog feilet';
$lang['dirnotemptyconfirm'] = 'Denne katalogen er ikke tom. Vil du virkelig slette den og alt innhold, inkludert underkataloger?';
$lang['dirtreedeletecancelled'] = 'Sletting av kataloger avbrutt';
$lang['imsure'] = 'Jeg er sikker!';
$lang['cancel'] = 'Avbryt';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'Last opp ny(e) fil(er):';
$lang['unpackafterupload'] = 'Fors&oslash;k &aring; pakke opp filen etter opplasting (kun tgz og de fleste zip-filer)?';
$lang['uploadsuccess'] = 'ble lastet opp';
$lang['uploadfail'] = 'opplastingen feilet ';
$lang['unpacksuccess'] = 'ble pakket ut';
$lang['unpackfail'] = 'feilet med denne feilmeldingen:';
$lang['packfileopenfail'] = 'Kunne ikke &aring;pne den pakkede filen for utpakking (format som ikke st&oslash;ttes?)';
$lang['packfilewritefail'] = 'Kunne ikke &aring;pne filen %s for skriving';
$lang['containsillegalchars'] = 'Filnavnet inneholder et eller flere ugyldige tegn (&#039;,&quot;,+,*,\,/,&amp;,$)';
$lang['currentpath'] = 'Gjeldende bane:';
$lang['newdirname'] = 'Opprett ny katalog:';
$lang['newdirsuccess'] = 'Katalogen ble opprettet';
$lang['newdirfail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; opprette katalogen';
$lang['invalidnewdir'] = 'Navnet p&aring; katalogen kan ikke inneholde tegn som  /, \ og &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s ';
$lang['iconsize'] = 'Ikon st&oslash;rrelse';
$lang['smallicons'] = 'Sm&aring; ikoner';
$lang['largeicons'] = 'Store ikoner';
$lang['thousanddelimiter'] = 'tusen skilletegn';
$lang['none'] = 'Ingen';
$lang['space'] = 'mellomrom';
$lang['showthumbnails'] = 'Vis miniatyrbilder';
$lang['showthumbnailshelp'] = '&Aring; sl&aring; p&aring; dette vil vise miniatyrbildene for bilderfiler om disse eksisterer og vil skjule de faktiske miniatyrbildefilene. &Aring; sl&aring; av vil vise alle filer.';
$lang['uploadfilesto'] = 'Laste opp filer til:';
$lang['uploadview'] = 'Last opp filer';
$lang['uploadboxes'] = 'Antall opplastingsbokser';
$lang['nothinguploaded'] = 'Ingenting lastet opp';
$lang['unsupportedarchive'] = 'Ikke st&oslash;ttet arkivformat';
$lang['uploadmethod'] = 'Opplastingsmetode';
$lang['uploaderstandard'] = 'Standard html innskrivingsmetode (tillater utpakking)';
$lang['enableadvanced'] = 'Sl&aring; p&aring; avansert modus?';
$lang['advancedhelp'] = 'Lar deg f&aring; tilgang til hele cmsms filsystemet, ikke kun /uploads/ (om tillatt)';
$lang['showhiddenfileshelp'] = 'Bare brukt om avansert mode er p&aring;sl&aring;tt';
$lang['showhiddenfiles'] = 'Vis skjulte filer';
$lang['settingsconfirmsingledelete'] = 'Bekreft sletting av en enkelt fil?';
$lang['settingssaved'] = 'Innstillinger lagret';
$lang['help'] = '		<h3>Hva gj&oslash;r denne?</h3>
		<p>Denne modulen tilbyr filbehandlingsfunksjoner.</p>
		<h3>Hvordan bruker jeg denne?</h3>
		<p>Velg den fra innholdsmenyen i  administrasjon.</p>';
$lang['utmz'] = '156861353.1250297380.1752.42.utmccn=(referral)|utmcsr=helminsen.no|utmcct=/install/upgrade.php|utmcmd=referral';
$lang['utma'] = '156861353.179052623084110100.1210423577.1255265025.1255273279.1976';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.3.10.1255273279';
?>

==> cmsmadesimple-1.9.4p4.tgz: cms/modules/FileManager/lang/ext/nb_NO.php <==
<?php
$lang['friendlyname'] = 'Filbehandler';
$lang['permission'] = 'Bruk av Filbehandler modulen';
$lang['permissionadvanced'] = 'Avansert bruk av Filbehandler modulen';
$lang['moddescription'] = 'Behandling av filer og kataloger i opplasting(uploads)-filseksjonen av cmsms';
$lang['installed'] = 'Filbehandler versjon %s installert';
$lang['postinstall'] = 'Filbehandler modul ble installert';
$lang['uninstalled'] = 'Filbehandler modul avinstallert';
$lang['really_uninstall'] = 'Er du sikker p&aring; at Filbehandler modulen skal avinstalleres';
$lang['upgraded'] = 'Filbehandler modulen ble oppgradert til versjon %s';
$lang['fileview'] = 'Fil visning';
$lang['switchtofileview'] = 'Skift til fil visning';
$lang['settings'] = 'Innstillinger';
$lang['savesettings'] = 'Lagre innstillinger';
$lang['postletexists'] = 'Advarsel! Vennligst fjern modules/File Manager/postlet katalogen helt, da dette har blitt foreldet for mange, mange versjoner siden.';
$lang['filename'] = 'Filnavn';
$lang['fileinfo'] = 'Filinfo ';
$lang['fileowner'] = 'Fileier';
$lang['fileperms'] = 'Tillatelser';
$lang['filesize'] = 'St&oslash;rrelse';
$lang['filedate'] = 'Dato';
$lang['actions'] = 'Handlinger';
$lang['delete'] = 'Slett';
$lang['notwritable'] = 'Ikke skrivbar';
$lang['afileistoobig'] = 'En fil er for stor. Opplasting avbrutt.';
$lang['unknown'] = 'Ukjent';
$lang['fileoutsideuploads'] = 'Du har IKKE tillatelse til &aring; modifisere filer utenfor uploads katalogen! (Dette vil kreve at du har tildelt Advanced File Management tillatelsen)';
$lang['writable'] = 'Skrivbar';
$lang['writeprotected'] = 'Skrivebeskyttet';
$lang['bytes'] = 'bytes ';
$lang['kb'] = 'kb ';
$lang['mb'] = 'Mb';
$lang['files'] = 'filer';
$lang['bytesin'] = 'bytes i';
$lang['in'] = 'i';
$lang['file'] = 'fil';
$lang['fileno'] = 'Filnr.';
$lang['subdirs'] = 'underkataloger';
$lang['subdir'] = 'underkatalog';
$lang['and'] = 'og';
$lang['confirmsingledelete'] = 'Er du sikker?';
$lang['confirmsingledirdelete'] = 'Er du sikker p&aring; at mappen skal slettes?';
$lang['dirtreedeletesuccess'] = 'Mappen inkludert innhold ble slettet.';
$lang['dirtreedeletefail'] = 'En feil oppstod under sletting av denne katalogen. Noe av innholdet kan likevel ha blitt slettet.';
$lang['singlefiledeletesuccess'] = 'Filen ble slettet';
$lang['filedeletesuccess'] = 'ble slettet';
$lang['singlefiledeletefail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; slette filen';
$lang['filedeletefail'] = ' ble ikke slettet grunnet en feil';
$lang['singledirdeletesuccess'] = 'Katalogen ble slettet';
$lang['singledirdeletefail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; slette katalogen (er den tom?)';
$lang['deleteselected'] = 'Slett de valgte filene';
$lang['confirmselected'] = 'Er du sikker?';
$lang['confirmdeleteselected'] = 'Er du sikker p&aring; at de valgte filene skal slettes?';
$lang['deleteselectedcancelled'] = 'Sletting av valgte filer avbrutt';
$lang['recursetext'] = 'Recurse into subdirs (not yet implemented)';
$lang['nofilesselected'] = 'Ingen filer valgt';
$lang['moveselected'] = 'Flytt de valgte filene';
$lang['copyselected'] = 'Kopier de valgte filene';
$lang['selecttargetdir'] = 'Velg m&aring;lmappe for &aring; flytte/kopiere';
$lang['movedto'] = 'flyttet til';
$lang['copiedto'] = 'kopiert til';
$lang['couldnotmove'] = 'kunne ikke flyttes';
$lang['couldnotcopy'] = 'kunne ikke kopieres';
$lang['filesdeletedsuccessfully'] = '%s fil(er) ble slettet';
$lang['filesdeletedfiled'] = '%s fil(er) feilet i &aring; bli slettet';
$lang['filesmovedsuccessfully'] = '%s fil(er) ble flyttet';
$lang['filesmovedfailed'] = '%s fil(er) feilet i &aring; bli flyttet';
$lang['filescopiedsuccessfully'] = '%s fil(er) ble kopiert';
$lang['filescopiedfailed'] = '%s fil(er) feilet i &aring; bli kopiert';
$lang['internalerror'] = 'Intern feil (betyr at noe ikke hadde mening i det hele tatt, vennligst rapporter hva du gjorde)';
$lang['rename'] = 'Omd&oslash;p';
$lang['newname'] = 'Nytt navn:';
$lang['renamesuccess'] = 'Filen ble omd&oslash;pt';
$lang['renamefailure'] = 'Omd&oslash;ping feilet';
$lang['renamecancelled'] = 'Omd&oslash;ping avbrutt';
$lang['owner'] = 'Eier(Owner)';
$lang['group'] = 'Gruppe(Group)';
$lang['others'] = 'Andre(Others)';
$lang['newpermissions'] = 'Nye rettigheter:';
$lang['setpermissions'] = 'Sett rettigheter';
$lang['permissionstyle'] = 'Rettighets stil';
$lang['rwxstyle'] = 'rwx stil';
$lang['755style'] = '755 stil';
$lang['quickmode'] = 'Quick chmod (f.eks. 777)';
$lang['chmod'] = 'Endre rettigheter';
$lang['chmodselected'] = 'Endre rettigheter p&aring; valgte filer';
$lang['chmodsuccess'] = 'Filen fikk nye rettigheter';
$lang['chmodfailure'] = 'Endring av rettigheter p&aring; filen feilet';
$lang['chmodcancelled'] = 'Endring av rettigheter avbrutt';
$lang['newuploadfailed'] = '%s fil(er) feilet i &aring; bli lastet opp (eller muligens &aring; pakke ut)';
$lang['newuploadsuccess'] = '%s fil(er) ble lastet opp (og pakket ut om dette var valgt)';
$lang['dirchmodfailmulti'] = '&Aring; endre rettigheter p&aring; katalogen mislyktes, men mulig noe av innholdet likevel kan ha f&aring;tt nye rettigheter.';
$lang['dirchmodsuccessmulti'] = 'Endre rettigheter p&aring; katalogen og dets innhold var vellykket';
$lang['dirchmodsuccess'] = 'Katalogen ble vellykket endret med nye rettigheter';
$lang['dirchmodfailure'] = 'Endring av rettigheter p&aring; katalog feilet';
$lang['dirnotemptyconfirm'] = 'Denne katalogen er ikke tom. Vil du virkelig slette den og alt innhold, inkludert underkataloger?';
$lang['dirtreedeletecancelled'] = 'Sletting av kataloger avbrutt';
$lang['imsure'] = 'Jeg er sikker!';
$lang['cancel'] = 'Avbryt';
$lang['ok'] = 'OK ';
$lang['uploadnewfile'] = 'Last opp ny(e) fil(er):';
$lang['unpackafterupload'] = 'Fors&oslash;k &aring; pakke opp filen etter opplasting (kun tgz og de fleste zip-filer)?';
$lang['uploadsuccess'] = 'ble lastet opp';
$lang['uploadfail'] = 'opplastingen feilet ';
$lang['unpacksuccess'] = 'ble pakket ut';
$lang['unpackfail'] = 'feilet med denne feilmeldingen:';
$lang['packfileopenfail'] = 'Kunne ikke &aring;pne den pakkede filen for utpakking (format som ikke st&oslash;ttes?)';
$lang['packfilewritefail'] = 'Kunne ikke &aring;pne filen %s for skriving';
$lang['afilecontainsillegalchars'] = 'Et filnavn inneholder en eller flere ugyldige tegn (&#039;,&quot;,+,*,\,/,&amp;,$). Opplasting avbrutt.';
$lang['currentpath'] = 'Gjeldende bane:';
$lang['newdirname'] = 'Opprett ny katalog:';
$lang['newdirsuccess'] = 'Katalogen ble opprettet';
$lang['newdirfail'] = 'En feil oppstod under fors&oslash;k p&aring; &aring; opprette katalogen';
$lang['direxists'] = 'Katalogen eksisterer allerede';
$lang['invalidnewdir'] = 'Navnet p&aring; katalogen kan ikke inneholde tegn som  /, \ og &#039;..&#039; ';
$lang['filedateformat'] = 'm/d/Y H:m:s ';
$lang['iconsize'] = 'Ikon st&oslash;rrelse';
$lang['smallicons'] = 'Sm&aring; ikoner';
$lang['largeicons'] = 'Store ikoner';
$lang['thousanddelimiter'] = 'tusen-skilletegn';
$lang['none'] = 'Ingen';
$lang['space'] = 'mellomrom';
$lang['showthumbnails'] = 'Vis miniatyrbilder';
$lang['showthumbnailshelp'] = '&Aring; sl&aring; p&aring; dette vil vise miniatyrbildene for bilderfiler om disse eksisterer og vil skjule de faktiske miniatyrbildefilene. &Aring; sl&aring; av vil vise alle filer.';
$lang['uploadfilesto'] = 'Laste opp filer til:';
$lang['uploadview'] = 'Last opp filer';
$lang['uploadboxes'] = 'Antall opplastingsbokser';
$lang['nothinguploaded'] = 'Ingenting lastet opp';
$lang['newunsupportedarchive'] = '%s er et ust&oslash;ttet arkivformat';
$lang['uploadmethod'] = 'Opplastingsmetode';
$lang['uploaderstandard'] = 'Standard html innskrivingsmetode (tillater utpakking)';
$lang['enableadvanced'] = 'Sl&aring; p&aring; avansert modus?';
$lang['advancedhelp'] = 'Lar deg f&aring; tilgang til hele cmsms filsystemet, ikke kun /uploads/ (om tillatt)';
$lang['showhiddenfileshelp'] = 'Bare brukt om avansert mode er p&aring;sl&aring;tt';
$lang['showhiddenfiles'] = 'Vis skjulte filer';
$lang['settingsconfirmsingledelete'] = 'Bekreft sletting av en enkelt fil?';
$lang['settingssaved'] = 'Innstillinger lagret';
$lang['help'] = '		<h3>Hva gj&oslash;r denne?</h3>
		<p>Denne modulen tilbyr filbehandlingsfunksjoner.</p>
		<h3>Hvordan bruker jeg denne?</h3>
		<p>Velg den fra innholdsmenyen i  administrasjon.</p>';
$lang['utmz'] = '156861353.1292071197.3458.79.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,49989.0/topicseen.html';
$lang['utma'] = '156861353.179052623084110100.1210423577.1295649999.1295715489.3513';
$lang['qca'] = '1210971690-27308073-81952832';
$lang['utmb'] = '156861353.1.10.1295715489';
$lang['utmc'] = '156861353';
?>
